@@ -5,10 +5,10 @@ from pathlib import Path
 from collections import namedtuple
 from argparse import ArgumentParser, RawTextHelpFormatter, RawDescriptionHelpFormatter
 
-from das.modules.add import AddMasscanOutput, AddRustscanOutput
+from das.modules.add import AddMasscanOutput, AddRustscanOutput, AddNaabuOutput
 from das.modules.scan import ScanShow, ScanRun
 from das.modules.report import NmapMerger
-from das.modules.common import BANNER, print_info, print_success, print_error, start_timer, stop_timer
+from das.modules.common import BANNER, Logger
 
 
 def parse_args():
@@ -26,9 +26,10 @@ def parse_args():
 	examples:
 
 	  das add masscan '-e eth0 --rate 1000 -iL hosts.txt --open -p1-65535'
-	  das add -db testdb -rm rustscan '-b 1000 -t 2000 -u 5000 -a hosts.txt -r 1-65535 -g --no-config --scan-order "Random"'
+	  das add rustscan '-b 1000 -t 2000 -u 5000 -a hosts.txt -r 1-65535 -g --no-config --scan-order "Random"'
+	  das add -db testdb -rm naabu '-interface eth0 -rate 1000 -iL hosts.txt -p - -silent -s s'
 	""".replace('\t', '')
-	add_parser = subparser.add_parser('add', formatter_class=RawDescriptionHelpFormatter, epilog=add_epilog, help='run a full port scan {masscan,rustscan} and add the output to DB')
+	add_parser = subparser.add_parser('add', formatter_class=RawDescriptionHelpFormatter, epilog=add_epilog, help='run a full port scan {masscan,rustscan,naabu} and add the output to DB')
 	add_parser.add_argument('scanner_name', action='store', type=str, help='port scanner name')
 	add_parser.add_argument('scanner_args', action='store', type=str, help='port scanner switches and options')
 	add_parser.add_argument('-db', action='store', type=str, default='das', help='DB name to save the output into')
@@ -91,8 +92,10 @@ def main():
 		print(BANNER)
 		sys.exit(0)
 
+	logger = Logger()
+
 	if args.subparser == 'add' or args.subparser == 'scan' and not args.show:
-		timestart = start_timer()
+		logger.start_timer()
 
 	if args.subparser == 'add':
 		(Path.cwd() / '.db' / 'raw').mkdir(parents=True, exist_ok=True)
@@ -101,8 +104,10 @@ def main():
 			AddPortscanOutput = AddMasscanOutput
 		elif args.scanner_name == 'rustscan':
 			AddPortscanOutput = AddRustscanOutput
+		elif args.scanner_name == 'naabu':
+			AddPortscanOutput = AddNaabuOutput
 		else:
-			print_error(f'{args.scanner_name}: Unsupported port scanner')
+			logger.print_error(f'{args.scanner_name}: Unsupported port scanner')
 			sys.exit(1)
 
 		P = Path.cwd() / '.db' / f'{args.db}.json'
@@ -111,13 +116,13 @@ def main():
 		portscan_out, num_of_hosts = apo.parse()
 
 		if P.exists():
-			print_info(f'Using DB -> {P.resolve()}')
+			logger.print_info(f'Using DB -> {P.resolve()}')
 
 		P = Path.cwd() / portscan_out
 		if P.exists():
-			print_info(f'Raw port scanner output -> {P.resolve()}')
+			logger.print_info(f'Raw port scanner output -> {P.resolve()}')
 
-		print_success(f'Successfully updated DB with {num_of_hosts} hosts')
+		logger.print_success(f'Successfully updated DB with {num_of_hosts} hosts')
 
 	elif args.subparser == 'scan':
 		(Path.cwd() / '.nmap').mkdir(exist_ok=True)
@@ -126,7 +131,7 @@ def main():
 
 		P = Path.cwd() / '.db' / f'{args.db}.json'
 		if P.exists():
-			print_info(f'Using DB -> {P.resolve()}')
+			logger.print_info(f'Using DB -> {P.resolve()}')
 
 		if args.show:
 			ss = ScanShow(str(P), args.hosts, args.ports)
@@ -160,7 +165,7 @@ def main():
 			nm.generate()
 
 	if args.subparser == 'add' or args.subparser == 'scan' and not args.show:
-		stop_timer(timestart)
+		logger.stop_timer()
 
 
 if __name__ == '__main__':
